import es, cfglib, cmdlib, langlib, playerlib, popuplib, services

info = es.AddonInfo()
info.name = 'LooneyCommands'
info.basename = info.name.lower()
info.version = '1.1'
info.url = 'http://addons.eventscripts.com/addons/view/LooneyCommands'
info.author = 'Satoon101'
es.ServerVar('%s_version'%info.basename,info.version,'%s Version'%info.name).makepublic()

addonpath = es.getAddonPath(info.basename)

config = cfglib.AddonCFG(addonpath + '/lc_config.cfg')
config.text('****************************\n// ** LooneyCommands Options **\n// ****************************')
lc_main_command = config.cvar('lc_main_command','@commands','Set to command to bring up commands menu')
config.write()

ini = cfglib.AddonINI(addonpath + '/commands.ini')
ini_comments = [
    'Place all of your player commands in this file',
    '',
    'Please use the same syntax for each:',
    '[<command to run>]',
    '<language> = "<string to show in menu for given language>"',
    '<2nd language> = "<string to show in menu for given language>"',
    'auth_level = "<authorization level>"',
    '',
    'For auth_level, you need to put an authorization flag',
    'I have provided 4 new authorization flags with the script',
    'looneycommands_ADMIN is for Admin level (also if you are using Basic_Auth)',
    'looneycommands_POWERUSER is for POWERUSER level',
    'looneycommands_IDENTIFIED is for IDENTIFIED level',
    'looneycommands_UNRESTRICTED is for ALL users',
    'If you are using something like Group_Auth, you can use your own flag to discern between users',
    '',
    'Continue adding any/all languages you might need for your server',
    '',
    'For say commands, please prefix them with "say" as in the second example',
              ]

length = len(ini)
ini.setInitialComments(ini_comments)
ini.addValueToGroup('Main Menu','en','Choose Command to run:')
ini.addValueToGroup('No Commands','en','#green[LooneyCommands]#default Sorry, you are not authorized for any commands')
if not length:
    ini.addValueToGroup('admin','en','Mani Admin Menu')
    ini.addValueToGroup('say !menu','en','Super Admin Menu')
for command in ini:
    ini.setGroupComments(command,[])
    if not command in ('Main Menu','No Commands'):
        ini.addValueToGroup(command,'auth_level','looneycommands_UNRESTRICTED')
ini.write()

lc_lang = langlib.Strings(ini)

if services.isRegistered('auth'):
    auth = services.use('auth')
    auth.registerCapability('looneycommands_ADMIN',auth.ADMIN)
    auth.registerCapability('looneycommands_POWERUSER',auth.POWERUSER)
    auth.registerCapability('looneycommands_IDENTIFIED',auth.IDENTIFIED)
    auth.registerCapability('looneycommands_UNRESTRICTED',auth.UNRESTRICTED)
    auth_registered = True
else:
    auth_registered = False

PlayerList = {}

class Player:
    def __init__(self,userid):
        self.userid = userid
        self.lang = playerlib.getPlayer(self.userid).lang
        self.auth_commands = set()
        for command in ini:
            if not command in ('Main Menu','No Commands'):
                if not auth_registered or services.use('auth').isUseridAuthorized(self.userid,ini[command]['auth_level']):
                    self.auth_commands.add(command)
        if self.auth_commands:
            self.commands_menu = popuplib.easymenu('looneycommands_menu_%s'%self.userid,'choice',self.chosenCommand)
            self.commands_menu.settitle(lc_lang('Main Menu',lang=self.lang))
            for command in self.auth_commands:
                self.commands_menu.addoption(command,lc_lang(command,lang=self.lang))
    
    def sendCommandsMenu(self):
        if not self.auth_commands:
            es.tell(self.userid,'#multi',lc_lang('No Commands',lang=self.lang))
        else:
            self.commands_menu.send(self.userid)
    
    def chosenCommand(self,userid,choice,popupid):
        es.server.queuecmd('es_sexec %s %s'%(self.userid,choice))

def getUser(userid):
    userid = str(userid)
    if not userid in PlayerList:
        PlayerList[userid] = Player(userid)
    return PlayerList[userid]

def load():
    global lc_command
    config.execute()
    lc_command = str(lc_main_command)
    cmdlib.registerSayCommand(lc_command,sendCommandsMenu,'Send Commands Menu')
    cmdlib.registerClientCommand(lc_command,sendCommandsMenu,'Send Commands Menu')

def unload():
    cmdlib.unregisterSayCommand(lc_command)
    cmdlib.unregisterClientCommand(lc_command)

def sendCommandsMenu(userid,args):
    getUser(userid).sendCommandsMenu()